# NOT RUN {
# (a) Comparison of means:
# This is a matched cluster randomized trials. The type ="M" indicates the comparison of
# means. The mean responses of a test group is mu1 = 0.06 and a reference group is mur =
# 0.4. The standard deviationof within cluster and between cluster are sig.w = 0.69 and
# sig.bm = 0.224 respectively, m = 20 indicates number of subject in each cluster. alpha
# =.05 is the level of significance and the probability of type-II error is beta = 0.10.
crt.match(type="M",mu1=0.6,mu2=0.4,alpha=0.05,beta=0.20,sig.w=0.69,sig.bm=0.224,m=20)
# (b) Comparison of proportions:
# This is a matched cluster randomized trials. Where type = "P" indicates the tests for
# comparison of proportions. The proportion of a test group is mu1 =0.01 and a reference
# group is mur = 0.0075. The Standard deviation of between cluster is sig.bm=0.224 and m
# = 2750 indicates number of subject in each cluster, alpha = 0.05 is the level of signi
# -ficance and probability of type-II error is beta = 0.10.
crt.match(type="P",mu1=0.01,mu2=0.0075,alpha=0.05,beta=0.10,sig.bm=0.0075,m=2750)
#(c) Comparison of incidence rates:
# This is a matched cluster randomized trials. Where type = "IR" indicates the tests the
# comparison of incidence rates. The incidence rate of a test group is mu1 = 4.5 and for
# reference group is mur = 3.6. A total of m = 50 person years is considered, alpha =.05
# is the level ofsignificance and the probability of type-II error is beta = 0.10. k=0.3
# indicates the common value of the coefficient of variation for each group.
crt.match(type="IR",mu1=4.5,mu2=3.6,alpha=0.05,beta=0.20,m=50,k=0.3)
# }
Run the code above in your browser using DataLab